#require File.expand_path(File.dirname(__FILE__) + '/spec_helper')
require "spec_helper"

describe Gradient, "gradients" do
  let(:multiple_colors_and_locations) do
    "-webkit-gradient(linear, 0% 40%, 0% 100%, from(#EEF1F6), to(#E6154D), color-stop(.923,#999999),color-stop(.1,#999999),color-stop(.6,#999999))"
  end
  let(:objc_multiple_colors_and_locations) do
"""
#define UIColorFromRGB(rgbValue) [UIColor colorWithRed:((float)((rgbValue & 0xFF0000) >> 16))/255.0 green:((float)((rgbValue & 0xFF00) >> 8))/255.0 blue:((float)(rgbValue & 0xFF))/255.0 alpha:1.0]
gradient.locations = [NSArray arrayWithObjects:[NSNumber numberWithFloat:0.1],[NSNumber numberWithFloat:0.4],[NSNumber numberWithFloat:0.6],[NSNumber numberWithFloat:0.923],[NSNumber numberWithFloat:1.0],nil];
gradient.colors = [NSArray arrayWithObjects:(id)UIColorFromRGB(0x999999).CGColor,(id)UIColorFromRGB(0xEEF1F6).CGColor,(id)UIColorFromRGB(0x999999).CGColor,(id)UIColorFromRGB(0x999999).CGColor,(id)UIColorFromRGB(0xE6154D).CGColor,nil];
"""
end

  let(:two_colors_and_locations) do
    "-webkit-gradient(linear, 0% 0%, 0% 100%, from(#EEF1F6), to(#DEE3E6))"
  end
  let(:objc_two_colors_and_locations) do
"""
#define UIColorFromRGB(rgbValue) [UIColor colorWithRed:((float)((rgbValue & 0xFF0000) >> 16))/255.0 green:((float)((rgbValue & 0xFF00) >> 8))/255.0 blue:((float)(rgbValue & 0xFF))/255.0 alpha:1.0]
gradient.locations = [NSArray arrayWithObjects:[NSNumber numberWithFloat:0.0],[NSNumber numberWithFloat:1.0],nil];
gradient.colors = [NSArray arrayWithObjects:(id)UIColorFromRGB(0xEEF1F6).CGColor,(id)UIColorFromRGB(0xDEE3E6).CGColor,nil];
"""
  end
 
 let(:rgb_helper) do 
   "#define UIColorFromRGB(rgbValue) [UIColor colorWithRed:((float)((rgbValue & 0xFF0000) >> 16))/255.0 green:((float)((rgbValue & 0xFF00) >> 8))/255.0 blue:((float)(rgbValue & 0xFF))/255.0 alpha:1.0]"
 end
 let(:ui_color) {"(id)UIColorFromRGB(0x999999).CGColor,"}
 let(:gradient_color) do
   "gradient.colors = [NSArray arrayWithObjects:(id)UIColorFromRGB(0xEEF1F6).CGColor,(id)UIColorFromRGB(0xDEE3E6).CGColor,nil];" 
 end
 let(:gradient_location) do
   "gradient.locations = [NSArray arrayWithObjects:[NSNumber numberWithFloat:1.0],[NSNumber numberWithFloat:0.9],nil];"
 end
 let(:number_1) {"[NSNumber numberWithFloat:1.0],"}
 let(:number_09) {"[NSNumber numberWithFloat:0.9],"}

  describe Gradient, "parse gradients" do
    context "parse_gradient with multiple colours" do
      subject {Gradient.parse_gradient(multiple_colors_and_locations, :webkit)}
      it {should == objc_multiple_colors_and_locations }  
    end
    context "parse_gradient two colours" do
      subject {Gradient.parse_gradient(two_colors_and_locations, :webkit)}
      it {should == objc_two_colors_and_locations }  
    end
  end
  
  describe Gradient, "helpers" do
    context "generate_gradient_color_method" do
      subject {Gradient.generate_gradient_color_method(["EEF1F6", "DEE3E6"])}
      it {should == gradient_color}
    end
    context "generate_gradient_location_method" do
      subject {Gradient.generate_gradient_location_method([1, "0.9"])}
      it {should == gradient_location}
    end
    context "generate_rgb_helper" do
      subject {Gradient.generate_rgb_helper}
      it {should == rgb_helper }
    end

    context "ui_color_from_rgb" do 
      subject {Gradient.ui_color_from_rgb("999999")}
      it {should == ui_color}
    end

    describe "generate_ns_number from int and float-strings" do
      context "with integer" do
        subject {Gradient.generate_ns_number(1)}
        it {should == number_1 }
      end
      context "with float-like string" do
        subject {Gradient.generate_ns_number(" .9")}
        it {should == number_09 }
      end
    end  
  end
end
